var annotated_dup =
[
    [ "algorithms", "namespacealgorithms.html", [
      [ "heap", "classalgorithms_1_1heap.html", "classalgorithms_1_1heap" ]
    ] ],
    [ "application", "namespaceapplication.html", [
      [ "application_shell", "classapplication_1_1application__shell.html", "classapplication_1_1application__shell" ],
      [ "base_application", "classapplication_1_1base__application.html", "classapplication_1_1base__application" ],
      [ "callstack_tracker", "classapplication_1_1callstack__tracker.html", "classapplication_1_1callstack__tracker" ],
      [ "frame_tracking_instance", "classapplication_1_1frame__tracking__instance.html", "classapplication_1_1frame__tracking__instance" ],
      [ "command_parameter", "classapplication_1_1command__parameter.html", "classapplication_1_1command__parameter" ],
      [ "command_line", "classapplication_1_1command__line.html", "classapplication_1_1command__line" ],
      [ "hoople_service", "classapplication_1_1hoople__service.html", "classapplication_1_1hoople__service" ],
      [ "launch_manager", "classapplication_1_1launch__manager.html", "classapplication_1_1launch__manager" ],
      [ "stdio_redirecter", "classapplication_1_1stdio__redirecter.html", "classapplication_1_1stdio__redirecter" ],
      [ "shared_memory", "classapplication_1_1shared__memory.html", "classapplication_1_1shared__memory" ],
      [ "singleton_application", "classapplication_1_1singleton__application.html", "classapplication_1_1singleton__application" ]
    ] ],
    [ "basis", "namespacebasis.html", [
      [ "array", "classbasis_1_1array.html", "classbasis_1_1array" ],
      [ "int_array", "classbasis_1_1int__array.html", "classbasis_1_1int__array" ],
      [ "double_array", "classbasis_1_1double__array.html", "classbasis_1_1double__array" ],
      [ "astring", "classbasis_1_1astring.html", "classbasis_1_1astring" ],
      [ "a_sprintf", "classbasis_1_1a__sprintf.html", "classbasis_1_1a__sprintf" ],
      [ "base_string", "classbasis_1_1base__string.html", "classbasis_1_1base__string" ],
      [ "byte_array", "classbasis_1_1byte__array.html", "classbasis_1_1byte__array" ],
      [ "packable", "classbasis_1_1packable.html", "classbasis_1_1packable" ],
      [ "common", "classbasis_1_1common.html", "classbasis_1_1common" ],
      [ "attribute", "classbasis_1_1attribute.html", "classbasis_1_1attribute" ],
      [ "equalizable", "classbasis_1_1equalizable.html", "classbasis_1_1equalizable" ],
      [ "orderable", "classbasis_1_1orderable.html", "classbasis_1_1orderable" ],
      [ "base_logger", "classbasis_1_1base__logger.html", "classbasis_1_1base__logger" ],
      [ "base_synchronizer", "classbasis_1_1base__synchronizer.html", "classbasis_1_1base__synchronizer" ],
      [ "clonable", "classbasis_1_1clonable.html", "classbasis_1_1clonable" ],
      [ "nameable", "classbasis_1_1nameable.html", "classbasis_1_1nameable" ],
      [ "text_formable", "classbasis_1_1text__formable.html", "classbasis_1_1text__formable" ],
      [ "hoople_standard", "classbasis_1_1hoople__standard.html", null ],
      [ "text_streamable", "classbasis_1_1text__streamable.html", "classbasis_1_1text__streamable" ],
      [ "enhance_cpp", "classbasis_1_1enhance__cpp.html", null ],
      [ "environment", "classbasis_1_1environment.html", null ],
      [ "mutex", "classbasis_1_1mutex.html", "classbasis_1_1mutex" ],
      [ "auto_synchronizer", "classbasis_1_1auto__synchronizer.html", "classbasis_1_1auto__synchronizer" ],
      [ "outcome", "classbasis_1_1outcome.html", "classbasis_1_1outcome" ]
    ] ],
    [ "configuration", "namespaceconfiguration.html", [
      [ "registry_configurator", "classconfiguration_1_1registry__configurator.html", "classconfiguration_1_1registry__configurator" ],
      [ "application_configuration", "classconfiguration_1_1application__configuration.html", "classconfiguration_1_1application__configuration" ],
      [ "config_watcher", "classconfiguration_1_1config__watcher.html", "classconfiguration_1_1config__watcher" ],
      [ "configlet", "classconfiguration_1_1configlet.html", "classconfiguration_1_1configlet" ],
      [ "string_configlet", "classconfiguration_1_1string__configlet.html", "classconfiguration_1_1string__configlet" ],
      [ "int_configlet", "classconfiguration_1_1int__configlet.html", "classconfiguration_1_1int__configlet" ],
      [ "bounded_int_configlet", "classconfiguration_1_1bounded__int__configlet.html", "classconfiguration_1_1bounded__int__configlet" ],
      [ "configuration_list", "classconfiguration_1_1configuration__list.html", "classconfiguration_1_1configuration__list" ],
      [ "configurator", "classconfiguration_1_1configurator.html", "classconfiguration_1_1configurator" ],
      [ "ini_configurator", "classconfiguration_1_1ini__configurator.html", "classconfiguration_1_1ini__configurator" ],
      [ "ini_parser", "classconfiguration_1_1ini__parser.html", "classconfiguration_1_1ini__parser" ],
      [ "ini_roller", "classconfiguration_1_1ini__roller.html", "classconfiguration_1_1ini__roller" ],
      [ "section_manager", "classconfiguration_1_1section__manager.html", "classconfiguration_1_1section__manager" ],
      [ "system_values", "classconfiguration_1_1system__values.html", "classconfiguration_1_1system__values" ],
      [ "table_configurator", "classconfiguration_1_1table__configurator.html", "classconfiguration_1_1table__configurator" ],
      [ "variable_tokenizer", "classconfiguration_1_1variable__tokenizer.html", "classconfiguration_1_1variable__tokenizer" ]
    ] ],
    [ "cromp", "namespacecromp.html", [
      [ "cromp_client", "classcromp_1_1cromp__client.html", "classcromp_1_1cromp__client" ],
      [ "cromp_common", "classcromp_1_1cromp__common.html", "classcromp_1_1cromp__common" ],
      [ "cromp_security", "classcromp_1_1cromp__security.html", "classcromp_1_1cromp__security" ],
      [ "cromp_server", "classcromp_1_1cromp__server.html", "classcromp_1_1cromp__server" ],
      [ "cromp_transaction", "classcromp_1_1cromp__transaction.html", "classcromp_1_1cromp__transaction" ]
    ] ],
    [ "crypto", "namespacecrypto.html", [
      [ "blowfish_crypto", "classcrypto_1_1blowfish__crypto.html", "classcrypto_1_1blowfish__crypto" ],
      [ "rsa_crypto", "classcrypto_1_1rsa__crypto.html", "classcrypto_1_1rsa__crypto" ],
      [ "ssl_init", "classcrypto_1_1ssl__init.html", "classcrypto_1_1ssl__init" ]
    ] ],
    [ "filesystem", "namespacefilesystem.html", [
      [ "byte_filer", "classfilesystem_1_1byte__filer.html", "classfilesystem_1_1byte__filer" ],
      [ "directory", "classfilesystem_1_1directory.html", "classfilesystem_1_1directory" ],
      [ "directory_tree", "classfilesystem_1_1directory__tree.html", "classfilesystem_1_1directory__tree" ],
      [ "file_info", "classfilesystem_1_1file__info.html", "classfilesystem_1_1file__info" ],
      [ "file_time", "classfilesystem_1_1file__time.html", "classfilesystem_1_1file__time" ],
      [ "filename", "classfilesystem_1_1filename.html", "classfilesystem_1_1filename" ],
      [ "filename_list", "classfilesystem_1_1filename__list.html", "classfilesystem_1_1filename__list" ],
      [ "filename_tree", "classfilesystem_1_1filename__tree.html", "classfilesystem_1_1filename__tree" ],
      [ "fname_tree_creator", "classfilesystem_1_1fname__tree__creator.html", "classfilesystem_1_1fname__tree__creator" ],
      [ "file_transfer_header", "classfilesystem_1_1file__transfer__header.html", "classfilesystem_1_1file__transfer__header" ],
      [ "heavy_file_operations", "classfilesystem_1_1heavy__file__operations.html", "classfilesystem_1_1heavy__file__operations" ],
      [ "huge_file", "classfilesystem_1_1huge__file.html", "classfilesystem_1_1huge__file" ]
    ] ],
    [ "fix_project_references", "namespacefix__project__references.html", [
      [ "fix_project_references", "classfix__project__references_1_1fix__project__references.html", "classfix__project__references_1_1fix__project__references" ]
    ] ],
    [ "geometric", "namespacegeometric.html", [
      [ "angle", "classgeometric_1_1angle.html", "classgeometric_1_1angle" ],
      [ "double_angle", "classgeometric_1_1double__angle.html", "classgeometric_1_1double__angle" ],
      [ "cartesian_point", "classgeometric_1_1cartesian__point.html", "classgeometric_1_1cartesian__point" ],
      [ "cartesian_line", "classgeometric_1_1cartesian__line.html", "classgeometric_1_1cartesian__line" ],
      [ "cartesian_rectangle", "classgeometric_1_1cartesian__rectangle.html", "classgeometric_1_1cartesian__rectangle" ],
      [ "circle", "classgeometric_1_1circle.html", "classgeometric_1_1circle" ],
      [ "ellipse", "classgeometric_1_1ellipse.html", "classgeometric_1_1ellipse" ],
      [ "line", "classgeometric_1_1line.html", "classgeometric_1_1line" ],
      [ "point", "classgeometric_1_1point.html", "classgeometric_1_1point" ],
      [ "polygon", "classgeometric_1_1polygon.html", "classgeometric_1_1polygon" ],
      [ "rectangle", "classgeometric_1_1rectangle.html", "classgeometric_1_1rectangle" ],
      [ "screen_point", "classgeometric_1_1screen__point.html", "classgeometric_1_1screen__point" ],
      [ "screen_rectangle", "classgeometric_1_1screen__rectangle.html", "classgeometric_1_1screen__rectangle" ],
      [ "triangle", "classgeometric_1_1triangle.html", "classgeometric_1_1triangle" ],
      [ "rectangle_warper", "classgeometric_1_1rectangle__warper.html", "classgeometric_1_1rectangle__warper" ]
    ] ],
    [ "loggers", "namespaceloggers.html", [
      [ "combo_logger", "classloggers_1_1combo__logger.html", "classloggers_1_1combo__logger" ],
      [ "console_logger", "classloggers_1_1console__logger.html", "classloggers_1_1console__logger" ],
      [ "critical_events", "classloggers_1_1critical__events.html", "classloggers_1_1critical__events" ],
      [ "eol_aware", "classloggers_1_1eol__aware.html", "classloggers_1_1eol__aware" ],
      [ "file_logger", "classloggers_1_1file__logger.html", "classloggers_1_1file__logger" ],
      [ "filter_set", "classloggers_1_1filter__set.html", "classloggers_1_1filter__set" ],
      [ "program_wide_logger", "classloggers_1_1program__wide__logger.html", null ],
      [ "null_logger", "classloggers_1_1null__logger.html", "classloggers_1_1null__logger" ],
      [ "standard_log_base", "classloggers_1_1standard__log__base.html", null ]
    ] ],
    [ "mathematics", "namespacemathematics.html", [
      [ "averager", "classmathematics_1_1averager.html", "classmathematics_1_1averager" ],
      [ "int_averager", "classmathematics_1_1int__averager.html", "classmathematics_1_1int__averager" ],
      [ "chaos", "classmathematics_1_1chaos.html", "classmathematics_1_1chaos" ],
      [ "double_plus", "classmathematics_1_1double__plus.html", "classmathematics_1_1double__plus" ],
      [ "math_ops", "classmathematics_1_1math__ops.html", "classmathematics_1_1math__ops" ]
    ] ],
    [ "nodes", "namespacenodes.html", [
      [ "doubly_linked_list", "classnodes_1_1doubly__linked__list.html", "classnodes_1_1doubly__linked__list" ],
      [ "node", "classnodes_1_1node.html", "classnodes_1_1node" ],
      [ "basket", "classnodes_1_1basket.html", "classnodes_1_1basket" ],
      [ "packable_tree", "classnodes_1_1packable__tree.html", "classnodes_1_1packable__tree" ],
      [ "packable_tree_factory", "classnodes_1_1packable__tree__factory.html", "classnodes_1_1packable__tree__factory" ],
      [ "path", "classnodes_1_1path.html", "classnodes_1_1path" ],
      [ "singly_linked_list", "classnodes_1_1singly__linked__list.html", "classnodes_1_1singly__linked__list" ],
      [ "symbol_tree", "classnodes_1_1symbol__tree.html", "classnodes_1_1symbol__tree" ],
      [ "tree", "classnodes_1_1tree.html", "classnodes_1_1tree" ]
    ] ],
    [ "octopi", "namespaceoctopi.html", [
      [ "entity_data_bin", "classoctopi_1_1entity__data__bin.html", "classoctopi_1_1entity__data__bin" ],
      [ "octopus_entity", "classoctopi_1_1octopus__entity.html", "classoctopi_1_1octopus__entity" ],
      [ "octopus_request_id", "classoctopi_1_1octopus__request__id.html", "classoctopi_1_1octopus__request__id" ],
      [ "octopus_request_id_set", "classoctopi_1_1octopus__request__id__set.html", "classoctopi_1_1octopus__request__id__set" ],
      [ "infoton_id_pair", "classoctopi_1_1infoton__id__pair.html", "classoctopi_1_1infoton__id__pair" ],
      [ "infoton_list", "classoctopi_1_1infoton__list.html", null ],
      [ "identity_infoton", "classoctopi_1_1identity__infoton.html", "classoctopi_1_1identity__infoton" ],
      [ "identity_tentacle", "classoctopi_1_1identity__tentacle.html", "classoctopi_1_1identity__tentacle" ],
      [ "infoton", "classoctopi_1_1infoton.html", "classoctopi_1_1infoton" ],
      [ "octopus", "classoctopi_1_1octopus.html", "classoctopi_1_1octopus" ],
      [ "tentacle", "classoctopi_1_1tentacle.html", "classoctopi_1_1tentacle" ],
      [ "tentacle_helper", "classoctopi_1_1tentacle__helper.html", "classoctopi_1_1tentacle__helper" ],
      [ "unhandled_request", "classoctopi_1_1unhandled__request.html", "classoctopi_1_1unhandled__request" ],
      [ "unhandled_request_tentacle", "classoctopi_1_1unhandled__request__tentacle.html", "classoctopi_1_1unhandled__request__tentacle" ],
      [ "encryption_infoton", "classoctopi_1_1encryption__infoton.html", "classoctopi_1_1encryption__infoton" ],
      [ "encryption_tentacle", "classoctopi_1_1encryption__tentacle.html", "classoctopi_1_1encryption__tentacle" ],
      [ "encryption_wrapper", "classoctopi_1_1encryption__wrapper.html", "classoctopi_1_1encryption__wrapper" ],
      [ "unwrapping_tentacle", "classoctopi_1_1unwrapping__tentacle.html", "classoctopi_1_1unwrapping__tentacle" ],
      [ "entity_registry", "classoctopi_1_1entity__registry.html", "classoctopi_1_1entity__registry" ],
      [ "blank_entity_registry", "classoctopi_1_1blank__entity__registry.html", "classoctopi_1_1blank__entity__registry" ],
      [ "file_transfer_infoton", "classoctopi_1_1file__transfer__infoton.html", "classoctopi_1_1file__transfer__infoton" ],
      [ "file_transfer_tentacle", "classoctopi_1_1file__transfer__tentacle.html", "classoctopi_1_1file__transfer__tentacle" ],
      [ "octenc_key_record", "classoctopi_1_1octenc__key__record.html", "classoctopi_1_1octenc__key__record" ],
      [ "key_repository", "classoctopi_1_1key__repository.html", "classoctopi_1_1key__repository" ],
      [ "login_tentacle", "classoctopi_1_1login__tentacle.html", "classoctopi_1_1login__tentacle" ],
      [ "recursive_file_copy", "classoctopi_1_1recursive__file__copy.html", "classoctopi_1_1recursive__file__copy" ],
      [ "security_infoton", "classoctopi_1_1security__infoton.html", "classoctopi_1_1security__infoton" ],
      [ "simple_entity_registry", "classoctopi_1_1simple__entity__registry.html", "classoctopi_1_1simple__entity__registry" ]
    ] ],
    [ "org", null, [
      [ "feistymeow", null, [
        [ "algorithms", "namespaceorg_1_1feistymeow_1_1algorithms.html", [
          [ "BinarySearchTree< K extends Comparable", "classorg_1_1feistymeow_1_1algorithms_1_1BinarySearchTree_3_01K_01extends_01Comparable.html", null ],
          [ "RectangleIntersector", "classorg_1_1feistymeow_1_1algorithms_1_1RectangleIntersector.html", "classorg_1_1feistymeow_1_1algorithms_1_1RectangleIntersector" ],
          [ "SubstringFinder", "classorg_1_1feistymeow_1_1algorithms_1_1SubstringFinder.html", "classorg_1_1feistymeow_1_1algorithms_1_1SubstringFinder" ]
        ] ],
        [ "dragdrop", "namespaceorg_1_1feistymeow_1_1dragdrop.html", [
          [ "dragdrop_list_test", "classorg_1_1feistymeow_1_1dragdrop_1_1dragdrop__list__test.html", "classorg_1_1feistymeow_1_1dragdrop_1_1dragdrop__list__test" ],
          [ "dragdrop_tree_test", "classorg_1_1feistymeow_1_1dragdrop_1_1dragdrop__tree__test.html", "classorg_1_1feistymeow_1_1dragdrop_1_1dragdrop__tree__test" ],
          [ "DragonTransferHandler", "classorg_1_1feistymeow_1_1dragdrop_1_1DragonTransferHandler.html", "classorg_1_1feistymeow_1_1dragdrop_1_1DragonTransferHandler" ],
          [ "IDragonDropDataProvider", "interfaceorg_1_1feistymeow_1_1dragdrop_1_1IDragonDropDataProvider.html", "interfaceorg_1_1feistymeow_1_1dragdrop_1_1IDragonDropDataProvider" ],
          [ "ListTransferable", "classorg_1_1feistymeow_1_1dragdrop_1_1ListTransferable.html", "classorg_1_1feistymeow_1_1dragdrop_1_1ListTransferable" ]
        ] ],
        [ "encryption", "namespaceorg_1_1feistymeow_1_1encryption.html", [
          [ "UnixCrypt", "classorg_1_1feistymeow_1_1encryption_1_1UnixCrypt.html", null ]
        ] ],
        [ "example", "namespaceorg_1_1feistymeow_1_1example.html", [
          [ "ZSorter< T extends Comparable", "classorg_1_1feistymeow_1_1example_1_1ZSorter_3_01T_01extends_01Comparable.html", null ]
        ] ],
        [ "filesystem", "namespaceorg_1_1feistymeow_1_1filesystem.html", [
          [ "PathHelper", "classorg_1_1feistymeow_1_1filesystem_1_1PathHelper.html", "classorg_1_1feistymeow_1_1filesystem_1_1PathHelper" ]
        ] ],
        [ "networking", "namespaceorg_1_1feistymeow_1_1networking.html", [
          [ "BasicWebServer", "classorg_1_1feistymeow_1_1networking_1_1BasicWebServer.html", "classorg_1_1feistymeow_1_1networking_1_1BasicWebServer" ]
        ] ],
        [ "process", "namespaceorg_1_1feistymeow_1_1process.html", [
          [ "ethread", "classorg_1_1feistymeow_1_1process_1_1ethread.html", "classorg_1_1feistymeow_1_1process_1_1ethread" ]
        ] ],
        [ "system", "namespaceorg_1_1feistymeow_1_1system.html", [
          [ "RegistryEditor", "classorg_1_1feistymeow_1_1system_1_1RegistryEditor.html", null ],
          [ "RegistryEditorTestCase", "classorg_1_1feistymeow_1_1system_1_1RegistryEditorTestCase.html", "classorg_1_1feistymeow_1_1system_1_1RegistryEditorTestCase" ]
        ] ],
        [ "textual", "namespaceorg_1_1feistymeow_1_1textual.html", [
          [ "SimpleDictionary", "classorg_1_1feistymeow_1_1textual_1_1SimpleDictionary.html", "classorg_1_1feistymeow_1_1textual_1_1SimpleDictionary" ],
          [ "WordBreakFinder", "classorg_1_1feistymeow_1_1textual_1_1WordBreakFinder.html", "classorg_1_1feistymeow_1_1textual_1_1WordBreakFinder" ]
        ] ],
        [ "utility", "namespaceorg_1_1feistymeow_1_1utility.html", [
          [ "Extemporizer", "classorg_1_1feistymeow_1_1utility_1_1Extemporizer.html", null ],
          [ "Naming", "classorg_1_1feistymeow_1_1utility_1_1Naming.html", "classorg_1_1feistymeow_1_1utility_1_1Naming" ]
        ] ],
        [ "windowing", "namespaceorg_1_1feistymeow_1_1windowing.html", [
          [ "ExitListener", "classorg_1_1feistymeow_1_1windowing_1_1ExitListener.html", "classorg_1_1feistymeow_1_1windowing_1_1ExitListener" ],
          [ "WindowUtilities", "classorg_1_1feistymeow_1_1windowing_1_1WindowUtilities.html", null ]
        ] ]
      ] ],
      [ "gffs", null, [
        [ "application", "namespaceorg_1_1gffs_1_1application.html", [
          [ "MemoryFootprint", "classorg_1_1gffs_1_1application_1_1MemoryFootprint.html", null ],
          [ "ProgramTools", "classorg_1_1gffs_1_1application_1_1ProgramTools.html", null ]
        ] ],
        [ "cache", "namespaceorg_1_1gffs_1_1cache.html", [
          [ "TimedOutLRUCache", "classorg_1_1gffs_1_1cache_1_1TimedOutLRUCache.html", "classorg_1_1gffs_1_1cache_1_1TimedOutLRUCache" ]
        ] ],
        [ "compression", "namespaceorg_1_1gffs_1_1compression.html", [
          [ "PackTar", "classorg_1_1gffs_1_1compression_1_1PackTar.html", null ],
          [ "UnpackTar", "classorg_1_1gffs_1_1compression_1_1UnpackTar.html", "classorg_1_1gffs_1_1compression_1_1UnpackTar" ]
        ] ],
        [ "filesystem", "namespaceorg_1_1gffs_1_1filesystem.html", [
          [ "FileSystemHelper", "classorg_1_1gffs_1_1filesystem_1_1FileSystemHelper.html", null ]
        ] ],
        [ "io", "namespaceorg_1_1gffs_1_1io.html", [
          [ "IOUtils", "classorg_1_1gffs_1_1io_1_1IOUtils.html", null ]
        ] ],
        [ "network", "namespaceorg_1_1gffs_1_1network.html", [
          [ "DeadHostChecker", "classorg_1_1gffs_1_1network_1_1DeadHostChecker.html", null ],
          [ "URLDownloader", "classorg_1_1gffs_1_1network_1_1URLDownloader.html", null ]
        ] ],
        [ "version", "namespaceorg_1_1gffs_1_1version.html", [
          [ "Version", "classorg_1_1gffs_1_1version_1_1Version.html", "classorg_1_1gffs_1_1version_1_1Version" ],
          [ "VersionManager", "classorg_1_1gffs_1_1version_1_1VersionManager.html", "classorg_1_1gffs_1_1version_1_1VersionManager" ]
        ] ]
      ] ]
    ] ],
    [ "phrase_replacer", "namespacephrase__replacer.html", [
      [ "phrase_replacer", "classphrase__replacer_1_1phrase__replacer.html", "classphrase__replacer_1_1phrase__replacer" ]
    ] ],
    [ "processes", "namespaceprocesses.html", [
      [ "configured_applications", "classprocesses_1_1configured__applications.html", "classprocesses_1_1configured__applications" ],
      [ "ethread", "classprocesses_1_1ethread.html", "classprocesses_1_1ethread" ],
      [ "heartbeat", "classprocesses_1_1heartbeat.html", "classprocesses_1_1heartbeat" ],
      [ "char_star_array", "classprocesses_1_1char__star__array.html", "classprocesses_1_1char__star__array" ],
      [ "launch_process", "classprocesses_1_1launch__process.html", "classprocesses_1_1launch__process" ],
      [ "letter", "classprocesses_1_1letter.html", "classprocesses_1_1letter" ],
      [ "mail_stop", "classprocesses_1_1mail__stop.html", "classprocesses_1_1mail__stop" ],
      [ "mailbox", "classprocesses_1_1mailbox.html", "classprocesses_1_1mailbox" ],
      [ "OS_event", "classprocesses_1_1OS__event.html", "classprocesses_1_1OS__event" ],
      [ "post_office", "classprocesses_1_1post__office.html", "classprocesses_1_1post__office" ],
      [ "process_control", "classprocesses_1_1process__control.html", "classprocesses_1_1process__control" ],
      [ "process_entry", "classprocesses_1_1process__entry.html", "classprocesses_1_1process__entry" ],
      [ "process_entry_array", "classprocesses_1_1process__entry__array.html", null ],
      [ "rendezvous", "classprocesses_1_1rendezvous.html", "classprocesses_1_1rendezvous" ],
      [ "safe_callback", "classprocesses_1_1safe__callback.html", "classprocesses_1_1safe__callback" ],
      [ "callback_data_block", "classprocesses_1_1callback__data__block.html", "classprocesses_1_1callback__data__block" ],
      [ "safe_roller", "classprocesses_1_1safe__roller.html", "classprocesses_1_1safe__roller" ],
      [ "state_machine", "classprocesses_1_1state__machine.html", "classprocesses_1_1state__machine" ],
      [ "transition_map", "classprocesses_1_1transition__map.html", "classprocesses_1_1transition__map" ],
      [ "thread_cabinet", "classprocesses_1_1thread__cabinet.html", "classprocesses_1_1thread__cabinet" ]
    ] ],
    [ "sockets", "namespacesockets.html", [
      [ "base_address", "classsockets_1_1base__address.html", "classsockets_1_1base__address" ],
      [ "internet_address", "classsockets_1_1internet__address.html", "classsockets_1_1internet__address" ],
      [ "machine_uid", "classsockets_1_1machine__uid.html", "classsockets_1_1machine__uid" ],
      [ "internet_machine_uid", "classsockets_1_1internet__machine__uid.html", "classsockets_1_1internet__machine__uid" ],
      [ "machine_uid_array", "classsockets_1_1machine__uid__array.html", "classsockets_1_1machine__uid__array" ],
      [ "range_limiter", "classsockets_1_1range__limiter.html", "classsockets_1_1range__limiter" ],
      [ "raw_socket", "classsockets_1_1raw__socket.html", "classsockets_1_1raw__socket" ],
      [ "sequence_tracker", "classsockets_1_1sequence__tracker.html", "classsockets_1_1sequence__tracker" ],
      [ "socket_data", "classsockets_1_1socket__data.html", "classsockets_1_1socket__data" ],
      [ "socket_minder", "classsockets_1_1socket__minder.html", "classsockets_1_1socket__minder" ],
      [ "span_manager", "classsockets_1_1span__manager.html", "classsockets_1_1span__manager" ],
      [ "spocket", "classsockets_1_1spocket.html", "classsockets_1_1spocket" ],
      [ "subnet_calculator", "classsockets_1_1subnet__calculator.html", "classsockets_1_1subnet__calculator" ],
      [ "tcpip_stack", "classsockets_1_1tcpip__stack.html", "classsockets_1_1tcpip__stack" ],
      [ "communication_commons", "classsockets_1_1communication__commons.html", "classsockets_1_1communication__commons" ],
      [ "throughput_counter", "classsockets_1_1throughput__counter.html", "classsockets_1_1throughput__counter" ]
    ] ],
    [ "structures", "namespacestructures.html", [
      [ "amorph", "classstructures_1_1amorph.html", "classstructures_1_1amorph" ],
      [ "bit_vector", "classstructures_1_1bit__vector.html", "classstructures_1_1bit__vector" ],
      [ "rotating_byte_hasher", "classstructures_1_1rotating__byte__hasher.html", "classstructures_1_1rotating__byte__hasher" ],
      [ "checksums", "classstructures_1_1checksums.html", null ],
      [ "internal_hash_array", "classstructures_1_1internal__hash__array.html", "classstructures_1_1internal__hash__array" ],
      [ "hashing_algorithm", "classstructures_1_1hashing__algorithm.html", "classstructures_1_1hashing__algorithm" ],
      [ "hash_table", "classstructures_1_1hash__table.html", "classstructures_1_1hash__table" ],
      [ "hash_wrapper", "classstructures_1_1hash__wrapper.html", "classstructures_1_1hash__wrapper" ],
      [ "bucket", "classstructures_1_1bucket.html", "classstructures_1_1bucket" ],
      [ "int_hash", "classstructures_1_1int__hash.html", "classstructures_1_1int__hash" ],
      [ "matrix", "classstructures_1_1matrix.html", "classstructures_1_1matrix" ],
      [ "int_matrix", "classstructures_1_1int__matrix.html", "classstructures_1_1int__matrix" ],
      [ "string_matrix", "classstructures_1_1string__matrix.html", "classstructures_1_1string__matrix" ],
      [ "double_matrix", "classstructures_1_1double__matrix.html", "classstructures_1_1double__matrix" ],
      [ "memory_limiter", "classstructures_1_1memory__limiter.html", "classstructures_1_1memory__limiter" ],
      [ "pointer_hash", "classstructures_1_1pointer__hash.html", "classstructures_1_1pointer__hash" ],
      [ "roller", "classstructures_1_1roller.html", "classstructures_1_1roller" ],
      [ "int_roller", "classstructures_1_1int__roller.html", "classstructures_1_1int__roller" ],
      [ "set", "classstructures_1_1set.html", "classstructures_1_1set" ],
      [ "int_set", "classstructures_1_1int__set.html", "classstructures_1_1int__set" ],
      [ "string_set", "classstructures_1_1string__set.html", "classstructures_1_1string__set" ],
      [ "pointer_set", "classstructures_1_1pointer__set.html", "classstructures_1_1pointer__set" ],
      [ "stack", "classstructures_1_1stack.html", "classstructures_1_1stack" ],
      [ "static_memory_gremlin", "classstructures_1_1static__memory__gremlin.html", "classstructures_1_1static__memory__gremlin" ],
      [ "string_array", "classstructures_1_1string__array.html", "classstructures_1_1string__array" ],
      [ "string_hash", "classstructures_1_1string__hash.html", "classstructures_1_1string__hash" ],
      [ "string_hasher", "classstructures_1_1string__hasher.html", "classstructures_1_1string__hasher" ],
      [ "astring_hasher", "classstructures_1_1astring__hasher.html", "classstructures_1_1astring__hasher" ],
      [ "string_table", "classstructures_1_1string__table.html", "classstructures_1_1string__table" ],
      [ "internal_symbol_indexer", "classstructures_1_1internal__symbol__indexer.html", "classstructures_1_1internal__symbol__indexer" ],
      [ "internal_symbol_info", "classstructures_1_1internal__symbol__info.html", "classstructures_1_1internal__symbol__info" ],
      [ "internal_symbol_list", "classstructures_1_1internal__symbol__list.html", "classstructures_1_1internal__symbol__list" ],
      [ "symbol_table", "classstructures_1_1symbol__table.html", "classstructures_1_1symbol__table" ],
      [ "internal_pointer_hider", "classstructures_1_1internal__pointer__hider.html", "classstructures_1_1internal__pointer__hider" ],
      [ "sym_tab_apply_data", "structstructures_1_1sym__tab__apply__data.html", "structstructures_1_1sym__tab__apply__data" ],
      [ "unique_id", "classstructures_1_1unique__id.html", "classstructures_1_1unique__id" ],
      [ "orderable_unique_id", "classstructures_1_1orderable__unique__id.html", "classstructures_1_1orderable__unique__id" ],
      [ "unique_int", "classstructures_1_1unique__int.html", "classstructures_1_1unique__int" ],
      [ "version", "classstructures_1_1version.html", "classstructures_1_1version" ],
      [ "version_record", "classstructures_1_1version__record.html", "classstructures_1_1version__record" ]
    ] ],
    [ "synchronic", "namespacesynchronic.html", [
      [ "bundle_list", "classsynchronic_1_1bundle__list.html", null ],
      [ "list_manager", "classsynchronic_1_1list__manager.html", "classsynchronic_1_1list__manager" ],
      [ "list_synchronizer", "classsynchronic_1_1list__synchronizer.html", "classsynchronic_1_1list__synchronizer" ],
      [ "synchronizable", "classsynchronic_1_1synchronizable.html", "classsynchronic_1_1synchronizable" ]
    ] ],
    [ "test", null, [
      [ "java", null, [
        [ "semantics", "namespacetest_1_1java_1_1semantics.html", [
          [ "behavior_of_finally_when_exception_in_catch", "classtest_1_1java_1_1semantics_1_1behavior__of__finally__when__exception__in__catch.html", "classtest_1_1java_1_1semantics_1_1behavior__of__finally__when__exception__in__catch" ]
        ] ]
      ] ]
    ] ],
    [ "textual", "namespacetextual.html", [
      [ "byte_formatter", "classtextual_1_1byte__formatter.html", "classtextual_1_1byte__formatter" ],
      [ "list_parsing", "classtextual_1_1list__parsing.html", "classtextual_1_1list__parsing" ],
      [ "parser_bits", "classtextual_1_1parser__bits.html", "classtextual_1_1parser__bits" ],
      [ "string_manipulation", "classtextual_1_1string__manipulation.html", null ],
      [ "xml_generator", "classtextual_1_1xml__generator.html", "classtextual_1_1xml__generator" ],
      [ "xml_parser", "classtextual_1_1xml__parser.html", "classtextual_1_1xml__parser" ]
    ] ],
    [ "timely", "namespacetimely.html", [
      [ "clock_time", "classtimely_1_1clock__time.html", "classtimely_1_1clock__time" ],
      [ "day_in_year", "classtimely_1_1day__in__year.html", "classtimely_1_1day__in__year" ],
      [ "time_locus", "classtimely_1_1time__locus.html", "classtimely_1_1time__locus" ],
      [ "stopwatch", "classtimely_1_1stopwatch.html", "classtimely_1_1stopwatch" ],
      [ "time_control", "classtimely_1_1time__control.html", "classtimely_1_1time__control" ],
      [ "time_stamp", "classtimely_1_1time__stamp.html", "classtimely_1_1time__stamp" ],
      [ "timeable", "classtimely_1_1timeable.html", "classtimely_1_1timeable" ],
      [ "timer_driver", "classtimely_1_1timer__driver.html", "classtimely_1_1timer__driver" ]
    ] ],
    [ "unit_test", "namespaceunit__test.html", [
      [ "unit_base", "classunit__test_1_1unit__base.html", "classunit__test_1_1unit__base" ]
    ] ],
    [ "versions", "namespaceversions.html", [
      [ "version_checker", "classversions_1_1version__checker.html", "classversions_1_1version__checker" ],
      [ "version_ini", "classversions_1_1version__ini.html", "classversions_1_1version__ini" ]
    ] ],
    [ "bogon", "classbogon.html", "classbogon" ],
    [ "bookmark_tree", "classbookmark__tree.html", "classbookmark__tree" ],
    [ "broadcast_spocket_tester", "classbroadcast__spocket__tester.html", "classbroadcast__spocket__tester" ],
    [ "configurable", "classconfigurable.html", "classconfigurable" ],
    [ "filepointer", "structfilepointer.html", "structfilepointer" ],
    [ "IfParser", "structIfParser.html", "structIfParser" ],
    [ "inclist", "structinclist.html", "structinclist" ],
    [ "inner_mark_tree", "classinner__mark__tree.html", "classinner__mark__tree" ],
    [ "link_record", "classlink__record.html", "classlink__record" ],
    [ "listo_links", "classlisto__links.html", "classlisto__links" ],
    [ "manifest_chunk", "structmanifest__chunk.html", "structmanifest__chunk" ],
    [ "menu_base", "classmenu__base.html", "classmenu__base" ],
    [ "menu_common_base", "classmenu__common__base.html", "classmenu__common__base" ],
    [ "menu_item", "classmenu__item.html", "classmenu__item" ],
    [ "nechung_oracle", "classnechung__oracle.html", "classnechung__oracle" ],
    [ "spocket_tester", "classspocket__tester.html", "classspocket__tester" ],
    [ "symtab", "structsymtab.html", "structsymtab" ],
    [ "testing_statistics", "classtesting__statistics.html", "classtesting__statistics" ],
    [ "windows_firewall", "classwindows__firewall.html", null ],
    [ "write_build_config", "classwrite__build__config.html", "classwrite__build__config" ]
];